"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function isObject(raw, transform) {
    if (Array.isArray(raw)) {
        return Promise.reject();
    }
    var transformObject = transform(raw);
    var keys = Object.keys(transformObject);
    var promises = [];
    for (var key in transformObject) {
        promises.push(transformObject[key]);
    }
    Promise.all(promises)
        .then(function (resolvedValues) {
        var result = resolvedValues.reduce(function (resolvedObject, property, index) {
            resolvedObject[keys[index]] = property;
            return resolvedObject;
        }, transformObject);
        Promise.resolve(result);
    })
        .catch(Promise.reject);
}
exports.isObject = isObject;
function isArray(raw, transform) {
    if (!Array.isArray(raw)) {
        return false;
    }
    return raw.map(function (r) { return isObject(r, transform); }).every(identity);
}
exports.isArray = isArray;
function isBoolean(raw) {
    return typeof raw === 'boolean';
}
exports.isBoolean = isBoolean;
function isString(raw) {
    return typeof raw === 'string';
}
exports.isString = isString;
function isNumber(raw) {
    return typeof raw === 'number';
}
exports.isNumber = isNumber;
function isOptional(raw, checker) {
    if (raw === undefined || raw === null) {
        return true;
    }
    return checker(raw);
}
exports.isOptional = isOptional;
function checkAndWrap(rawData, checker) {
    return new Promise(function (resolve, reject) {
        // eslint-disable-next-line no-console
        console.log(rawData);
        var rawJson = JSON.parse(rawData);
        if (checker(rawJson)) {
            resolve(rawJson);
        }
        else {
            reject(new Error(rawData + " is invalid"));
        }
    });
}
exports.checkAndWrap = checkAndWrap;
